@@ -6,10 +6,13 @@ from __future__ import unicode_literals
 
 import argparse
 import datetime
+from functools import partial
 
 from .get import get_data
 from .get import most_recent_year
+from .models import _load_users
 from .utils import AOC_TZ
+from .utils import _cli_guess
 from .version import __version__
 
 
@@ -17,6 +20,7 @@ def main():
     aoc_now = datetime.datetime.now(tz=AOC_TZ)
     days = range(1, 26)
     years = range(2015, aoc_now.year + int(aoc_now.month == 12))
+    users = _load_users()
     parser = argparse.ArgumentParser(
         description="Advent of Code Data v{}".format(__version__),
         usage="aocd [day 1-25] [year 2015-{}]".format(years[-1]),
@@ -40,6 +44,8 @@ def main():
         action="version",
         version="%(prog)s v{}".format(__version__),
     )
+    if len(users) > 1:
+        parser.add_argument("-u", "--user", choices=users, type=partial(_cli_guess, choices=users))
     args = parser.parse_args()
     if args.day in years and args.year in days:
         # be forgiving
@@ -47,5 +53,9 @@ def main():
     if args.day not in days or args.year not in years:
         parser.print_usage()
         parser.exit(1)
-    data = get_data(day=args.day, year=args.year)
+    try:
+        session = users[args.user]
+    except (KeyError, AttributeError):
+        session = None
+    data = get_data(session=session, day=args.day, year=args.year)
     print(data)
