@@ -24,6 +24,8 @@ from termcolor import colored
 from termcolor import cprint
 
 from .exceptions import AocdError
+from .exceptions import DeadTokenError
+from .exceptions import UnknownUserError
 from .exceptions import PuzzleUnsolvedError
 from .exceptions import PuzzleLockedError
 from .utils import AOC_TZ
@@ -48,6 +50,15 @@ class User(object):
         self.token = token
         self._owner = "unknown.unknown.0"
 
+    @classmethod
+    def from_id(cls, id):
+        users = _load_users()
+        if id not in users:
+            raise UnknownUserError("User with id '{}' is not known".format(id))
+        user = cls(users[id])
+        user._owner = id
+        return user
+
     @property
     def auth(self):
         return {"session": self.token}
@@ -99,6 +110,9 @@ class User(object):
             response = requests.get(url, cookies=self.auth, headers=USER_AGENT)
             response.raise_for_status()
             soup = bs4.BeautifulSoup(response.text, "html.parser")
+            if soup.article.pre is None and "overall leaderboard" in soup.article.text:
+                msg = "the auth token ...{} is expired or not functioning"
+                raise DeadTokenError(msg.format(self.token[-4:]))
             stats_txt = soup.article.pre.text
             lines = stats_txt.splitlines()
             lines = [x for x in lines if x.split()[0] in days]
